==> pixelpay_sdk-2.0.3.tar.gz: lib/requests/card_tokenization.dart <==
import 'package:sprintf/sprintf.dart';
import 'package:pixelpay_sdk/base/helpers.dart';
import 'package:pixelpay_sdk/base/request_behaviour.dart';
import 'package:pixelpay_sdk/models/billing.dart';
import 'package:pixelpay_sdk/models/card.dart';

class CardTokenization extends RequestBehaviour {
	/// Card number or PAN
	String? number;

	/// Card security code
	String? cvv2;

	/// Card expire month date (MM)
	String? expire_month;

	/// Card expire year date (YYYY)
	String? expire_year;

	/// Cardholder name
	String? cardholder;

	/// Customer billing address
	String? address;

	/// Customer billing country alpha-2 code (ISO 3166-1)
	String? country;

	/// Customer billing state alpha code (ISO 3166-2)
	String? state;

	/// Customer billing city
	String? city;

	/// Customer billing postal code
	String? zip;

	/// Customer billing phone
	String? phone;

	/// Customer email
	String? email;

	/// Associate and mapping Card model properties to transaction
	/// 
	/// @param card
	void setCard(Card card) {
		number = Helpers.trimValue(card.number);
		cvv2 = card.cvv2;
		expire_month = sprintf('%02d', [card.expire_month]);
		expire_year = card.expire_year.toString();
		cardholder = Helpers.trimValue(card.cardholder);
	}

	/// Associate and mapping Billing model properties to transaction
	/// 
	/// @param billing
	void setBilling(Billing billing) {
		address = Helpers.trimValue(billing.address);
		country = billing.country;
		state = billing.state;
		city = Helpers.trimValue(billing.city);
		zip = billing.zip;
		phone = billing.phone;
	}
}

==> pixelpay_sdk-2.0.4.tar.gz: lib/requests/card_tokenization.dart <==
import 'package:sprintf/sprintf.dart';
import 'package:pixelpay_sdk/base/helpers.dart';
import 'package:pixelpay_sdk/base/request_behaviour.dart';
import 'package:pixelpay_sdk/models/billing.dart';
import 'package:pixelpay_sdk/models/card.dart';

class CardTokenization extends RequestBehaviour {
	/// Card number or PAN
	String? number;

	/// Card security code
	String? cvv2;

	/// Card expire month date (MM)
	String? expire_month;

	/// Card expire year date (YYYY)
	String? expire_year;

	/// Cardholder name
	String? cardholder;

	/// Customer billing address
	String? address;

	/// Customer billing country alpha-2 code (ISO 3166-1)
	String? country;

	/// Customer billing state alpha code (ISO 3166-2)
	String? state;

	/// Customer billing city
	String? city;

	/// Customer billing postal code
	String? zip;

	/// Customer billing phone
	String? phone;

	/// Customer email
	String? email;

	/// Associate and mapping Card model properties to transaction
	/// 
	/// @param card
	void setCard(Card card) {
		number = Helpers.replaceWhiteSpaces(Helpers.trimValue(card.number));
		cvv2 = card.cvv2;
		cardholder = Helpers.trimValue(card.cardholder);

    if (card.expire_month != null) {
		  expire_month = sprintf('%02d', [card.expire_month]);
    }

    if (card.expire_year != null) {
		  expire_year = card.expire_year.toString();
    }
	}

	/// Associate and mapping Billing model properties to transaction
	/// 
	/// @param billing
	void setBilling(Billing billing) {
		address = Helpers.trimValue(billing.address);
		country = billing.country;
		state = billing.state;
		city = Helpers.trimValue(billing.city);
		zip = billing.zip;
		phone = billing.phone;
	}
}
